#ifndef BORROWER_H
#define BORROWER_H
#include "FL/Fl_Check_Button.H"
#include <stdio.h>
#include <fstream>

class Borrower : public Fl_Check_Button {
 public:
  char* name;				//Borrower Name
  int id;				//Borrower ID
  int risk;				//Borrower's Risk
  Borrower* next;			//Pointer to next Borrower in linked list
  Borrower* prev;			//Pointer to previous Borrower in linked list
  

  //***************************Constructor****************************
  //Constructor creates a borrower object as a subclass of FLTK's
  //check button. Params include name, ID, risk, and pointer to the
  //previous borrower in the linked list.
  //******************************************************************
  Borrower(char* n, int ident, int riskfact,Borrower* previous):Fl_Check_Button(15,65,380,50," "){
    name = new char[65];
    strcpy(name,n);
    id = ident;
    prev = previous;
    next = NULL;
    risk = riskfact;
    char* labelstring = new char[500];
    sprintf(labelstring,"Borrower:%s   ID:%i   Risk:%i",n,id,risk);
    label(labelstring);
  }


  //**************************Default Constructor*********************
  //Default constructor creates a borrower as a subclass of FLTK's
  //check button. This also sets the next and previous pointers to NULL.
  //******************************************************************
  Borrower():Fl_Check_Button(15,65,380,50," "){
    next=NULL;
    prev=NULL;
  }


  //***********************writeBorrowerReport************************
  //This function creates the borrower report file. It takes in a
  //linked list of borrowers, and simply produces the report file.
  //******************************************************************
  void writeBorrowerReport(Borrower* list){
    ofstream fout("borrowers_report.txt");
    char output[100];
    while(list!=NULL){
      
      sprintf(output,"ID:%d  Name:%s  Risk:%d\n",list->id,list->name,list->risk);
      fout << output;
      list=list->next;
    }
    fout.close();
  }

};
#endif
