#ifndef BUNDLE_H
#define BUNDLE_H
#include "/home/CS/cs536/002/dgus7193/fltk/include/FL/Fl_Check_Button.H"
#include <stdio.h>
#include <fstream>

class Bundle : public Fl_Check_Button {
 public:
  int bundleID;				//ID of the bundle
  char bundleDate[40];			//Date of bundle creation
  char bundleInv[65];			//Investor who purchased the bundle
  float bundleCost;			//Cost of the bundle
  int bundleRisk;			//Risk of the bundle
  float bundleProfit;			//Profit to be made from bundle
  int loans[1000];			//Loans in the bundle (limit 1000)
  Bundle* next;				//Pointer to next bundle in linked list
  Bundle* prev;				//Pointer to previous bundle in linked list


  //*********************Constructor****************************
  //Constructor creates a bundle object subclassed as an FLTK
  //check button. Takes in bundle ID, investor name, bundle cost,
  //bundle risk, bundle profit, and a pointer to the previous
  //bundle in the linked list.
  //************************************************************
  Bundle(int bID, char* bDate, char* bInv, float bCost, int bRisk, float bProfit, Bundle* previous):Fl_Check_Button(15,65,380,75," "){
    bundleID = bID;
    strcpy(bundleDate,bDate);
    strcpy(bundleInv,bInv);
    bundleCost = bCost;
    bundleRisk = bRisk;
    bundleProfit = bProfit;
    prev = previous;
    next = NULL;

  }
  

  //**********************Default Constructor********************
  //Default constructor creates a bundle object subclassed as an
  //FLTK check button. It also sets the next and previous pointers
  //in the linked list to NULL.
  //*************************************************************
  Bundle():Fl_Check_Button(15,65,380,50,""){
    next = NULL;
    prev = NULL;
  }


  //***********************set_label*****************************
  //Sets the button label of a bundle object with approp. data
  //*************************************************************
  void set_label(){
    char* loans_in_b = new char[600];
    sprintf(loans_in_b,"Loan IDs:");
    for(int i=0; i<500; i++){
      if(loans[i+1]==-1) break;
	    sprintf(loans_in_b,"%s %d,",loans_in_b,loans[i]);
    }
    char* labelstring = new char[500];
    sprintf(labelstring,"ID:%d   Investor:%s   Date:%sCost:$%.2f   Risk:%d   Profit:$%.2f\n%s\n",bundleID,bundleInv,bundleDate,bundleCost,bundleRisk,bundleProfit,loans_in_b);
    label(labelstring);
  }


  //********************writeBundleReport************************
  //This function writes the bundle report file. It takes in the
  //linked list of bundles, and produces an output file with all
  //bundle information.
  //*************************************************************
  void writeBundleReport(Bundle* list){
    	ofstream fout("bundles_report.txt");
	Bundle* head = list;
	char* output = new char[250];
	while(list!=NULL){

	  char* loans_in_b = new char[600];
	  sprintf(loans_in_b,"Loan IDs:");
	  for(int i=0; i<500; i++){
	    if(list->loans[i+1]==-1) break;
	    sprintf(loans_in_b,"%s %d,",loans_in_b,list->loans[i]);
	  }
	  sprintf(output,"ID:%d   Date:%s   Investor:%s   Cost:$%.2f   Risk:%d   Profit:$%.2f\n%s\n",list->bundleID,list->bundleDate,list->bundleInv,list->bundleCost,list->bundleRisk,list->bundleProfit,loans_in_b);
      		fout << output << endl;
		list = list->next;
	}
    	fout.close();
	list = head;
  }

};
#endif

