/* SQL_UTIL.h */

#ifndef sql_util_h
#define sql_util_h

#include "Lender.h"
#include "Borrower.h"

void SigHandler(int);
int open_connection( void );
void disconnect( void );
void begin_transaction( void );
void commit_transaction( void );
void quick_connect( void );
void quick_disconnect( void );
void roll_forward( void );
void sql_error( void );


//Lender Crud functions

bool active_candidate( void );
//*****************************************************************
   // Params: None.
   // Inputs: None.
   // Outputs: None.
   // Return Value: bool 
   //                    
   //
   // Description: Returns True if the current user has candidate loans
   //
   //****************************************************************

bool update_lender( const char*, const char*, double );
   //*****************************************************************
   // Params: char* - contact name, char* - phone, double - ID
   // Inputs: None.
   // Outputs: None.
   // Return Value: bool - returns true if the database is successfully 
   //                      updated.
   //                      Returns false if there is an error in the 
   //                      database.
   //
   // Description: Takes the new values for a Lender contact name and phone
   //              number.  Uses Lender ID to search for correct Lender 
   //              to update.
   //
   //****************************************************************

bool create_lender( const char*, const char*, const char*, double );
   //*****************************************************************
   // Params: char* - name, char* - contact name, char* - phone, double - ID
   // Inputs: None.
   // Outputs: None.
   // Return Value: bool - returns true if the Lender is added to the
   //                      database successfully. 
   //                      Returns false if there is an error in the 
   //                      database.
   //
   // Description: Takes the new values for a Lender name, contact name,
   //              phone number, and ID to create a new entry of a Lender
   //              in the database.
   //
   //****************************************************************

bool deleteLenders(double id);
   //*****************************************************************
   // Params: double - id
   // Inputs: None.
   // Outputs: None.
   // Return Value: bool - returns true if the Lender is deleted from the
   //                      database successfully. 
   //                      Returns false if there is no matching LenderID,
   //                      or if the Lender is currently associated with any
   //                      loans.
   //
   // Description: Removes the Lender with the corresponding ID from the 
   //              database
   //
   //*****************************************************************

Lender* getLenders();
   //*****************************************************************
   // Params: None.
   // Inputs: None.
   // Outputs: None.
   // Return Value: Lender* - returns pointer to the head of the Lender list. 
   //                         returns NULL if there are no Lenders in the 
   //                         database.
   //
   // Description: Searches the database and builds a linked list of Lenders.
   //              The list is used to display the Lenders in the GUI.
   //
   //****************************************************************


//Borrower database functions

Borrower* getBorrowers();
   //*****************************************************************
   // Params: None.
   // Inputs: None.
   // Outputs: None.
   // Return Value: Borrower* - returns pointer to the head of the Borrower 
   //                           list. 
   //                           returns NULL if there are no Borrowers in the 
   //                           database.
   //
   // Description: Searches the database and builds a linked list of Borrowers.
   //              The list is used to display the Borrowers in the GUI.
   //
   //****************************************************************


#endif

















